$(function () {
    var errorLabel = $('#error_login_message');
    $('#login_form').submit(function(){
        errorLabel.hide();
        var form = $(this);
        $.post(form.attr('action'), form.serialize(), function (res) {
            if (!res.status) {
                errorLabel.show();
            } else {
                window.location = '';
            }
        });
        return false;
    });
});