<div class="wrap">
    <?php echo form_open('', array('class' => 'form_register')) ?>
    <div class="field-box">
        <label><?php echo $this->lang->line('E-mail'); ?><span>*</span></label>
        <input type="text" name="email" value="<?php echo $this->input->post('email'); ?>" required />
        <?php echo form_error('email', '<p class="error">'); ?>
    </div>
    <div class="field-box">
        <label><?php echo $this->lang->line('Name'); ?></label>
        <input type="text" name="name" value="<?php echo $this->input->post('name'); ?>"/>
    </div>
    <div class="field-box">
        <label><?php echo $this->lang->line('Surname'); ?></label>
        <input type="text" name="surname" value="<?php echo $this->input->post('surname'); ?>"/>
    </div>
    <div class="field-box">
        <label><?php echo $this->lang->line('Sex'); ?></label>
        <?php echo form_dropdown('sex', array(2 => 'Female', 1 => 'Male'), $this->input->post('sex')); ?>
    </div>
    <div class="field-box">
        <label><?php echo $this->lang->line('Phone'); ?></label>
        <input type="text" name="phone" value="<?php echo $this->input->post('phone'); ?>"/>
    </div>
    <div class="field-box">
        <label><?php echo $this->lang->line('Password'); ?><span>*</span></label>
        <input type="password" name="password" value="" required />
        <?php echo form_error('password', '<p class="error">'); ?>
    </div>
    <div class="field-box">
        <label><?php echo $this->lang->line('Password again'); ?><span>*</span></label>
        <input type="password" name="passconf" value="" required />
        <?php echo form_error('passconf', '<p class="error">'); ?>
    </div>
    <div class="checkbox-inline">                            
        <input type="checkbox" id="subscribe" name="subscribe" />
        <label class="check_label" for="subscribe"><?php echo $this->lang->line('Subscribe for news'); ?></label>
    </div>
    <div class="field-box">                            
        <input type="submit" class="big_orange" value="<?php echo $this->lang->line('Sign up') ?>" />
    </div>
    <?php echo form_close() ?>
</div>