<?php 

$config['csrf_protection'] = TRUE;

$config['registered_user_default_role_id'] = 3;

$config['registration_page'] = base_url('sign_up');
$config['forgot_password_page'] = base_url('forgotpassword');
$config['profile_page'] = base_url('profile');

$config['logged_in_redirect_page'] = '/';