<?php echo form_open('ajax/user/action/login', array('class' => 'form_register')) ?>
<div class="field-box">
    <label><?php echo $this->lang->line('E-mail') ?></label>
    <input type="text" name="login" required tabindex="1" value="<?= $login ?>"/>
</div>
<div class="field-box password-field">
    <label><?php echo $this->lang->line('Password') ?></label>
    <a href="/forgotpassword"><?php echo $this->lang->line('Forgot your password?') ?></a>
    <input type="password" name="password" required tabindex="2"/>
</div>
<?php if ($status === 'true') : ?>
    <p class="error"><?= $this->lang->line('Wrong login or password') ?></p>
<?php endif; ?>
<div class="field-box button-field-box"> 
    <a href="<?= $this->config->item('registration_page') ?>" class="register_link"><?php echo $this->lang->line('Sign up') ?></a>
    <input tabindex="3" type="submit" class="big_orange" value="<?php echo $this->lang->line('Sign in') ?>" />
</div>
<?php echo form_close() ?>